# Changelog

## 21.8.0 (2021-09-03)

* Version sync with `klio`

## 21.2.0 (2021-03-16)

* Version sync with `klio`

## 0.1.1 (2020-12-17)

### Removed

* Dropped support for Python 3.5 (reached its [end-of-life support](https://www.python.org/downloads/release/python-3510/))
* Removed unused `numpy` dependency.

## 0.1.0 (2020-10-06)

Initial general release (no change since `0.1.0.alpha1`).

## 0.1.0.alpha1 (2020-09-02)

First (preview) release of the `spotify-klio` library.
